"""
Module implements connection settings.
"""

from dataclasses import dataclass
from numbers import Real
from typing import Optional


@dataclass
class HTTPSettings:
    """
    Structure for http settings. Must be acceptable by BaseHTTPAPI.__init__.
    """

    api: int  #: api version
    origin: str  #: host origin, "http://127.0.0.1:xxxx"
    totalTimeout: Real = 60  #: request's processing  timeout in seconds.
    connectTimeout: Optional[Real] = None  #: connection timeout in seconds.
    sockConnectTimeout: Optional[Real] = None  #: socket connection timeout in seconds.
    sockReadTimeout: Optional[Real] = None  #: socket chunk read timeout in seconds.
    asyncRequest: bool = True  #: default mode for request async or blocking
